#!/bin/sh
# Code adapted by Margo Schulter from a shell script by
# Hudson Lacerda, developer of microabc. The credit for
# the original script and this fine set of utilities is
# his, but of course responsibility for the modifications,
# and especially the verbose commentary, is entirely mine.

# -- Generate Black Laundry MIDI files in Peppermint-24 scale --
# These files will use pitchbend, best with certain types of
# reverb options turned off on a player such as timidity++ (see 
# below). Other options would be to have microabc output an snt
# file and have Timidity retune on the fly when playing the MIDI
# (using this frequency table rather than pitch bends); or to 
# use Scala to retune a MIDI file (which like our approach here 
# involves pitch bends). Note that we name the resulting abc file
# BlackLaundrymidi.abc to show that it is meant for generating
# MIDI files with abc2midi rather than a PostScript or PDF score.

# IMPORTANT NOTE: Using abc2midi version 1.85 (June 25, 2006),
# error messages occur where it appears that an ABC 's:' field name
# (for symbol lines of text giving the tuning of a scale's notes
# in cents) is being confused with a music symbol: the error
# "Single colon in bar" is returned for four lines starting with
# this 's:', but it doesn't seem to affect the desired MIDI
# output (at least as long, I've been advised, as only numbers
# and decimal points are used in the annotations).

microabc -MBlackLaundry.abp -ipeppermint24.txt procsag:0 > BlackLaundrymidi.abc
abc2midi BlackLaundrymidi.abc
# We recommend timidity with -R8 --reverb=d option
# for these and other MIDI files with pitch bends. 
# Optionally one could do 
# timidity -R8 --reverb=d reverb=g,50 BlackLaundrymidi1.midi
# for a global reverb effect (in a range of 0-127, here 50)

# -- Generate PostScript and PDF score files using sagittal.pfb font --
# Here we use an .abp file with the '%%format sagittal-pfb.format'
# option. The file name BlackLaundrypfb.abp warns that we are
# going to produce a PostScript file with a font dependency.
# Note that if the format file is not in the current directory,
# we must also specify its path, thus if we are generating from 
# a first-level subdirectory of the microabc directory where 
# this file is kept, '%%format ../sagittal-pfb.format'

# NOTE: abcm2ps will as a default search for format files in the
# current directory and also the "default format directory" which
# can be displayed with the command 'abcm2ps -V'; in GNU/Linux, this 
# directory is /usr/local/share/abcm2ps -- while microabc-2006-07-10 
# does not copy the .fmt files to this directory during the 
# installation process, a user might do so, and future versions might
# automate the process with a makefile.    

# For the production of a PostScript score, we need Sagittal 
# processing on, that is, procsag:1 -- here set by way of the
# microabc command line switch -S.

# CAUTION: The PostScript file requires that our Type 1 font
# be present in PostScript virtual memory when the file is run, 
# but the PDF file includes it, neatly avoiding this complication.
# Thus when using this option, PDF distribution is best.
microabc -PBlackLaundrypfb.abp -S -i- > BlackLaundrypfb.abc
abcm2ps BlackLaundrypfb.abc -O BlackLaundrypfb.ps 

# File can now be viewed or printed provided PostScript
# printer or software interpreter (e.g. Ghostscript) has
# access to sagittal.pfb font; as a warning, a file name
# with *pfb.abp, *pfb.abc, or *pfb.ps warns of this
# font dependency. Now we generate a self-sufficent PDF.
# The 'ps2pdf12' option seeks better backward compatibility.
ps2pdf12 BlackLaundrypfb.ps BlackLaundry.pdf

# In addition to being freely portable while using the 
# higher-quality PostScript Type 1 font, the PDF file
# may be more compact than PostScript, another advantage.   

# -- Generate self-sufficient PostScript score --
# This will include the font information, but will not
# have the hinting information of the Type 1 format, and
# will be considerably larger than a PostScript file
# relying on sagittal.pfb or a self-sufficient PDF file.
# We use BlackLaundry.abp, with '%%format sagittal.fmt'
# option again specifying a path if the format file is
# in another directory, e.g. '%%format ../sagittal.fmt.' 
# Note that output file from microabc is named
# BlackLaundryps.abc to tell us that it is for use with 
# abc2mps in generating a score, rather for MIDI files.

# Again we need procsag:1, conveniently set with the 
# microabc -S switch.

microabc -PBlackLaundry.abp -S -i- > BlackLaundryps.abc
abcm2ps BlackLaundryps.abc -O BlackLaundry.ps
# Self-sufficient PostScript file should run on any
# PostScript printer or software interpreter supporting
# Level 2.

# We can also generate a PDF file from this PostScript 
# file which uses a Type 3 font.

ps2pdf12 BlackLaundry.ps BlackLaundryType3.pdf 

# -- Generate MIDI files in sagittal just intonation --

# We can also produce files using a just intonation 
# interpretation of the sagittal symbols, albeit with
# sometimes unpredictable results given that the music 
# was intended for the Peppermint 24 tuning system. 
# Actually Peppermint has close approximations of lots
# of just ratios, but not necessarily the same ones or 
# in the same positions that will be selected here. 
# Still, it's a very useful procedure when the standard 
# sagittal JI ratios _are_ intended, and otherwise makes
# an interesting experiment. (Retuning MIDI files to 
# unlikely systems for the music being altered is
# something of of a sport among some microtonal 
# enthusiasts.) So we'll try it here!

# As it happens, the result is more of a pleasant
# coloristic variation than anything so radically
# astounding. We get in effect a tuning of two
# 12-note Pythagorean chains of fifths at a just
# 33:32 (about 53.273 cents) apart, with the regular
# Pythagorean intervals (the "historically correct"
# choice for this kind of 13th-14th century style)
# not too far from their Peppermint sizes. The
# final cadence, with a 445-cent major third, 943-cent 
# major sixth, and 53-cent semitones (at 128:99,
# 512:297, and 33:32) is actually a bit more dramatic
# or ebullient than in Peppermint (with sizes of around
# 437, 933, and 59 cents, including a just 12:7 sixth).
# We get different "colors" or "flavors" of a cadence
# with major third expanding to fifth and major sixth
# to octave, with the sagittal JI reading a kind of
# middle solution between the septimal flavor of
# Peppermint and some readings of Marchettus of Padua
# calling for a third and sixth around 13:10 and 26:15 
# or the like (say around 450 and 950 cents or a tad
# larger).  

# Note that this JI rendition is simpler for microabc 
# to handle, and requires only one step of processing 
# rather than the two for the Peppermint tuning to 
# produce an abc file for abc2midi. The 'procsag:1'
# option for microabc directs that Sagittal pitch 
# conversions should take place, the correct choice 
# for this JI reading. Although 'procsag:1' is not 
# strictly required with microabc-2006-07-10, it 
# is required for later versions where 'procsag:0' 
# ("do not do conversion of Sagittal pitches") is
# the default. 

# Here the longer procsag:1 is used to turn on
# Sagittal processing, although -S is available
# in recent versions of microabc.

microabc -i- -MBlackLaundry.abp procsag:1 > BlackLaundrymidipure.abc
abc2midi BlackLaundrymidipure.abc
